<?php

namespace BoUk\PageViewsCounter\Controllers;

/**
 * 
 */
class pvcController
{

	/**
	 * [$model description]
	 * @var [type]
	 */
	protected $model;

	/**
	 * [__construct description]
	 * @param \BoUk\PageViewsCounter\Models\pvcModel $model [description]
	 */
	public function __construct( \BoUk\PageViewsCounter\Models\pvcModel $model )
	{
		$this->model 	= $model;

		/**
		 * Add required JS, for triggering view counter increment
		 */
		add_action( 'wp_enqueue_scripts', [
				$this,
				'enqueueScripts' 
			]);

		/**
		 * Load JS asynchronously
		 */
		add_filter( 'script_loader_tag', [
				$this->model,
				'addAsyncAttribute'
			], 10, 2);
	}

	/**
	 * [scheduleCronEvent description]
	 * @return [type] [description]
	 */
	public function scheduleCronEvent()
	{
		if ( ! wp_next_scheduled( $this->model->cronEvent ) ) 
    		wp_schedule_event( time(),  $this->model->cronSchedule,  $this->model->cronEvent );
	}

	/**
	 * [enqueueScripts description]
	 * @return [type] [description]
	 */
	public function enqueueScripts()
	{
		global $post;

		if ( ! is_singular() || $post->post_status != 'publish' )
			return;

		wp_enqueue_script( 
			'pageviews-counter',
    		BPVC_PLUGIN_URL . 'assets/src/js/pageviews.js',
    		[ 'jquery' ],
    		BPVC_PLUGIN_VERSION,
    		true
		);

		wp_localize_script(
			'pageviews-counter', 
			'pc_vars',[
                'ajax_url' 	=> BPVC_PLUGIN_URL . 'ajax/counter.php',
                'postID' 	=> $post->ID
            ]
        );
	}

	/**
	 * [storeViews description]
	 * @return [type] [description]
	 */
	public function storeViews()
	{
		$cacheInstance = $this->model->setCacheManager();

		$counters = $this->model->getAllCounters( $cacheInstance );				

		if ( ! $counters )
			return;		

		foreach( $counters as $counter )
		{						
			$key = $counter->getKey();						
			$views = $this->model->getViews( $cacheInstance, $key );			

			if ( ! $views )
				return;

			$result = $this->model->updateViews( $key, $views );

			if ( $result )
				$cacheInstance->deleteItem( $key );
		}
	}

	/**
	 * [pvColumnContent description]
	 * @param  [type] $name   [description]
	 * @param  [type] $postId [description]
	 * @return [type]         [description]
	 */
	public function pvColumnContent( $name, $postId )
	{
		if ( $name == 'pageviews' ) 
		{
          $pageviews = get_post_meta( $postId, '_pageviews', true );
          
          if ( $pageviews )           
            echo intval( $pageviews );          
          
          else 
            echo '-';          
      }
	}

	/**
	 * Action executed on plugin deactivation
	 * @return [type] [description]
	 */
	public function deactivate()
	{
		do_action( 'pc_plugin_deactivate' );
	}

	/**
	 * [removeCronEvents description]
	 * @return [type] [description]
	 */
	public function removeCronEvents()
	{
		$timestamp = wp_next_scheduled( $this->model->cronEvent );
		wp_unschedule_event( $timestamp, $this->model->cronEvent );
	}

}