<?php
/*
Plugin Name: PageViews Counter
Description: Lightweight pageviews counter.
Version: 1.1.2
Author: Petr Paboucek -aka- BoUk
Author URI: https://wpadvisor.co.uk
Text Domain: pageviews-counter
*/

if ( ! defined( 'ABSPATH' ) ) 
    exit;

define( 'BPVC_PLUGIN_PATH', 	plugin_dir_path( __FILE__ ) );
define( 'BPVC_PLUGIN_URL', 		plugin_dir_url( __FILE__ ) );
define( 'BPVC_PLUGIN_VERSION', 	'1.1.0' );

/**
 * Load required files
 */
require BPVC_PLUGIN_PATH . "vendor/autoload.php";

$model 		= new \BoUk\PageViewsCounter\Models\pvcModel();
$controller = new \BoUk\PageViewsCounter\Controllers\pvcController( $model );

/**
 * Adding custom cron schedule required for regular fetch of counters 
 * from storage
 */
add_filter( 'cron_schedules', [ 
				$model, 			
				'addCronSchedules' 
			]);

/**
 * Making sure re-occuring cron event is set
 */
add_action( 'init',	[ 
				$controller, 
				'scheduleCronEvent' 
			]);	

/**
 * Custom cron action. Move counters from temporary storage into DB
 */
add_action( $model->cronEvent, [ 
				$controller, 
				'storeViews' 
			]);

/**
 * Clean up after deactivation
 */
register_deactivation_hook( __FILE__, [ 
				$controller, 
				'deactivate' 
			]);

/**
 * Remove re-occuring cron event
 */
add_action( 'pc_plugin_deactivate', [
				$controller, 
				'removeCronEvents' 
			]);

/**
 * Add extra column with pageviews into posts admin screen
 */
add_filter( 'manage_posts_columns', [ 
				$model, 
				'addPvColumn' 
			]);

/**
 * Add extra column with pageviews into pages admin screen
 */
add_filter( 'manage_pages_columns', [ 
				$model, 
				'addPvColumn' 
			]);

/**
 * Fetches pageviews from custom post meta
 */
add_action( 'manage_posts_custom_column', [ 
				$controller, 
				'pvColumnContent' 
			], 
			10, 2 );

add_action( 'manage_pages_custom_column', [ 
				$controller, 
				'pvColumnContent' 
			], 
			10, 2 );    